package org.richfaces.cdk;

import static org.easymock.EasyMock.eq;
import static org.easymock.EasyMock.expect;

import java.util.HashMap;
import java.util.Map;

import javax.faces.component.UIComponent;
import javax.faces.component.UIComponentBase;
import javax.faces.context.ResponseWriter;

import org.easymock.EasyMock;
import org.jboss.test.faces.mock.MockFacesEnvironment;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;


public class FooTest {

    private static final String TEXT_FOR_TEST = "text for test";

    private MockFacesEnvironment environment;
    
    private UIComponent component;
    
    private ResponseWriter responseWriter;
    
    private Map<String, Object> attributesMap;
    
    @Before
    public void setUp() throws Exception {
        //create mock environment
        environment = MockFacesEnvironment.createEnvironment();

        //create mock component
        component = environment.createMock(UIComponentBase.class);
        
        //create mock response writer
        responseWriter = environment.createMock(ResponseWriter.class);
        expect(environment.getFacesContext().getResponseWriter()).andStubReturn(responseWriter);
        
        //set up attributes map
        attributesMap = new HashMap<String, Object>();
        expect(component.getAttributes()).andStubReturn(attributesMap);
    }
    
    @After
    public void tearDown() throws Exception {
        //do verification for mocked objects
        environment.verify();

        //do clean up
        environment.release();
        environment = null;
        
        component = null;
        responseWriter = null;
        attributesMap = null;
    }
    
    @Test
    public void testMockRenderer() throws Exception {
        //set attribute values for this test
        attributesMap.put("shouldWriteValue", Boolean.TRUE);
        attributesMap.put("value", TEXT_FOR_TEST);
        
        //record expectations
        responseWriter.writeText(eq(TEXT_FOR_TEST), EasyMock.<String>isNull());
        
        //switch to "replay" state
        environment.replay();

        //execute action
        FooRenderer fooRenderer = new FooRenderer();
        fooRenderer.encodeEnd(environment.getFacesContext(), component);
    }
}
